@@ -37,6 +37,10 @@ namespace Conversions
   Glib::ustring get_text_for_gda_value(Field::glom_field_type glom_type, const Gnome::Gda::Value& value, const NumericFormat& numeric_format = NumericFormat());
   Glib::ustring get_text_for_gda_value(Field::glom_field_type glom_type, const Gnome::Gda::Value& value, const std::locale& locale, const NumericFormat& numeric_format = NumericFormat(), bool iso_format = false);
 
+  //This is easier than using the GdaNumeric API,
+  //which normally involves text-to-number parsing.
+  double get_double_for_gda_value_numeric(const Gnome::Gda::Value& value);
+
   Glib::ustring format_time(const tm& tm_data);
   Glib::ustring format_time(const tm& tm_data, const std::locale& locale, bool iso_format = false);
   Glib::ustring format_date(const tm& tm_data);
@@ -59,8 +63,8 @@ namespace Conversions
 
   Gnome::Gda::Value get_example_value(Field::glom_field_type field_type);
 
+  ///Get a string representing binary data, for SQL
   Glib::ustring get_escaped_binary_data(guint8* buffer, size_t buffer_size);
-  Gnome::Gda::Value parse_escaped_binary_data(const Glib::ustring& escaped_data);
 
   Gnome::Gda::Value convert_value(const Gnome::Gda::Value& value, Field::glom_field_type target_glom_type);
 
