@@ -42,6 +42,11 @@
 
 #ifndef G_OS_WIN32
 #include <fontconfig/fontconfig.h> //For cleanup.
+#else
+#define SAVE_DATADIR DATADIR
+#undef DATADIR
+#include <winsock2.h>
+#define DATADIR SAVE_DATADIR
 #endif
 
 namespace Glom
@@ -84,14 +89,26 @@ OptionGroup::OptionGroup()
 
 } //namespace Glom
 
+#ifndef G_OS_WIN32
 extern "C" void __libc_freeres(void);
+#endif
 
 int 
 main(int argc, char* argv[])
 {
+#ifndef G_OS_WIN32
   //Force some cleanup at exit,
   //to help valgrind to detect memory leaks:
   atexit(__libc_freeres);
+#else
+  WSADATA data;
+  int errcode = WSAStartup(MAKEWORD(2, 0), &data);
+  if(errcode != 0)
+  {
+    std::cerr << "Failed to initialize WinSock: " << errcode << std::endl;
+    return -1;
+  }
+#endif
 
   // TODO: I am not sure why, but this does not work. PYTHONPATH is set
   // correctly according to getenv(), but python still does not look in it.
@@ -144,6 +161,10 @@ main(int argc, char* argv[])
 
   Glom::OptionGroup group;
   context.set_main_group(group);
+  //We use python for calculated-fields:
+  Py_Initialize();
+  PySys_SetArgv(argc, argv);
+  Gtk::Main mainInstance(argc, argv, context);
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
@@ -191,15 +212,10 @@ main(int argc, char* argv[])
     return 0;
   }
 
-  //We use python for calculated-fields:
-  Py_Initialize();
-  PySys_SetArgv(argc, argv);
-
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
 #endif
   {
-    Gtk::Main mainInstance(argc, argv, context);
     Bakery::init();
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -299,6 +315,9 @@ main(int argc, char* argv[])
   //These fail, probably because of previous things that are causing leaks:
   //cairo_debug_reset_static_data(); //This crashes with _cairo_hash_table_destroy: Assertion `hash_table->live_entries == 0' failed.
   //FcFini(); //This crashes with "FcCacheFini: Assertion `fcCacheChains[i] == ((void *)0)' failed."
+#ifdef G_OS_WIN32
+  WSACleanup();
+#endif
 
   return 0;
 }
