@@ -34,8 +34,7 @@ namespace Glom
 
 Box_Data_List::Box_Data_List()
 : m_has_one_or_more_records(false),
-  m_read_only(false),
-  m_reset_column_widths(false)
+  m_read_only(false)
 {
   m_layout_name = "list";
 
@@ -435,10 +434,6 @@ void Box_Data_List::create_layout_add_group(const sharedptr<LayoutGroup>& layout
         }
       }
 
-      //Sometimes we reset the column width so that new fields are easily visible:
-      if(m_reset_column_widths)
-        child_item->set_display_width(0);
-
       m_AddDel.add_column(child_item);
     }
   }
@@ -446,7 +441,8 @@ void Box_Data_List::create_layout_add_group(const sharedptr<LayoutGroup>& layout
 
 Document_Glom::type_list_layout_groups Box_Data_List::create_layout_get_layout()
 {
-  //Overriden in Box_Data_List_Related:
+  //This method is overriden in Box_Data_List_Related.
+
   return get_data_layout_groups(m_layout_name); 
 }
 
@@ -587,10 +583,7 @@ void Box_Data_List::get_record_counts(gulong& total, gulong& found) const
 //overridden, so we can change the column widths, so they are all visible:
 void Box_Data_List::on_dialog_layout_hide()
 {
-  //Tell create_layout() to reset the display_width for each layout item:
-  m_reset_column_widths = true;
   Box_Data::on_dialog_layout_hide();
-  m_reset_column_widths = false;
 }
 
 Dialog_Layout* Box_Data_List::create_layout_dialog() const
