@@ -56,7 +56,7 @@ protected:
   virtual void save_to_document();
 
   //signal handlers:
-  virtual void on_button_field_add(); //override
+  virtual void on_button_add_field(); //override
   virtual void on_button_edit(); //override
  
   void on_combo_relationship_changed();
