@@ -22,15 +22,18 @@
 #define GLOM_UTILITY_WIDGETS_BUTTON_GLOM_H
 
 #include <gtkmm.h>
-#include "layoutwidgetbase.h"
+#include "layoutwidgetutils.h"
 #include <glom/libglom/data_structure/layout/layoutitem_button.h>
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class App_Glom;
 
 class ButtonGlom
 : public Gtk::Button,
-  public LayoutWidgetBase
+  public LayoutWidgetUtils
 {
 public:
   explicit ButtonGlom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
@@ -41,7 +44,13 @@ protected:
   void init();
 
   virtual App_Glom* get_application();
+#ifndef GLOM_ENABLE_CLIENT_ONLY    
+  virtual void on_menu_properties_activate();
+  virtual bool on_button_press_event(GdkEventButton *event);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_BUTTON_GLOM_H
 
